@@ -1,21 +1,19 @@
 package Bitcoin::Crypto::Key::ExtPrivate;
 
-our $VERSION = "0.997";
+our $VERSION = "1.000";
 
 use v5.10;
 use warnings;
 use Moo;
 use Crypt::Mac::HMAC qw(hmac);
-use Encode qw(encode decode);
-use Unicode::Normalize;
 use Bitcoin::BIP39 qw(gen_bip39_mnemonic bip39_mnemonic_to_entropy entropy_to_bip39_mnemonic);
-use Crypt::KeyDerivation qw(pbkdf2);
 use Scalar::Util qw(blessed);
 
 use Bitcoin::Crypto::BIP44;
 use Bitcoin::Crypto::Key::ExtPublic;
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Helpers qw(new_bigint pad_hex ensure_length verify_bytestring);
+use Bitcoin::Crypto::Util qw(mnemonic_to_seed);
 use Bitcoin::Crypto::Exception;
 
 use namespace::clean;
@@ -62,8 +60,6 @@ sub mnemonic_from_entropy
 sub from_mnemonic
 {
 	my ($class, $mnemonic, $password, $lang) = @_;
-	$mnemonic = encode("UTF-8", NFKD(decode("UTF-8", $mnemonic)));
-	$password = encode("UTF-8", NFKD(decode("UTF-8", "mnemonic" . ($password // ""))));
 
 	if (defined $lang) {
 
@@ -78,9 +74,8 @@ sub from_mnemonic
 			}
 		);
 	}
-	my $bytes = pbkdf2($mnemonic, $password, 2048, "SHA512", 64);
 
-	return $class->from_seed($bytes);
+	return $class->from_seed(mnemonic_to_seed($mnemonic, $password));
 }
 
 sub from_seed
@@ -229,23 +224,23 @@ see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bit
 
 =head2 generate_mnemonic
 
-	sig: generate_mnemonic($class, $len = 128, $lang = "en")
+	$mnemonic = $class->generate_mnemonic($len = 128, $lang = "en")
 
-Generates a new mnemonic code. Default entropy is 128 bits.
-With $len this can be changed to up to 256 bits with 32 bit step.
+Generates a new mnemonic code using L<Bytes::Random::Secure>. Default entropy is 128 bits.
+With C<$len> this can be changed to up to 256 bits with 32 bit step.
 
 Other languages than english require additional modules for L<Bitcoin::BIP39>.
 
-Dies when $len is invalid (under 128, above 256 or not divisible by 32).
 Returns newly generated BIP39 mnemonic string.
+Dies when C<$len> is invalid (under 128, above 256 or not divisible by 32).
 
 In some environments a problem may be encountered that causes the secure random bytes generator to block the program execution (See L<Bytes::Random::Secure/"BLOCKING ENTROPY SOURCE">). In this case you can use I<mnemonic_from_entropy> and pass in entropy generated by L<Bytes::Random::Secure> in non-blocking mode (via the OO interface).
 
 =head2 mnemonic_from_entropy
 
-	sig: mnemonic_from_entropy($class, $bytes, $lang = "en")
+	$mnemonic = $class->mnemonic_from_entropy($bytes, $lang = "en")
 
-Generates a new mnemonic code from custom entropy given in $bytes (a bytestring). This entropy should be of the same bit size as in L</"generate_mnemonic">. Returns newly generated BIP39 mnemonic string.
+Generates a new mnemonic code from custom entropy given in C<$bytes> (a bytestring). This entropy should be of the same bit size as in L</"generate_mnemonic">. Returns newly generated BIP39 mnemonic string.
 
 This can be useful to avoid relying on the underlying implementation of L<Bitcoin::BIP39>.
 
@@ -255,81 +250,83 @@ Be aware that the method you use to generate a mnemonic will be a very important
 
 =head2 from_mnemonic
 
-	sig: from_mnemonic($class, $mnemonic, $password = "", $lang = undef)
+	$key_object = $class->from_mnemonic($mnemonic, $password = "", $lang = undef)
 
 Creates a new key from given mnemonic and password.
 
 Note that technically any password is correct and there's no way to tell if it was mistaken.
 
-If you need to validate if $mnemonic is a valid mnemonic you should specify $lang, e.g. "en".
+If you need to validate if C<$mnemonic> is a valid mnemonic you should specify C<$lang>, e.g. "en".
 
-If no $lang is given then any string passed as $mnemonic will produce a valid key.
+If no C<$lang> is given then any string passed as C<$mnemonic> will produce a valid key.
 
 Returns a new instance of this class.
 
+B<Important note about unicode:> this function only accepts UTF8-decoded strings (both C<$mnemonic> and C<$password>), but can't detect whether it got it or not. This will only become a problem if you use non-ascii mnemonic and/or password. If there's a possibility of non-ascii, always use utf8 and set binmodes to get decoded (wide) characters to avoid problems recovering your wallet.
+
 =head2 from_seed
 
-	sig: from_seed($class, $seed)
+	$key_object = $class->from_seed($seed)
 
-Creates and returns a new key from seed, which can be any data of any length.  $seed is expected to be a byte string.
+Creates and returns a new key from seed, which can be any data of any length. C<$seed> is expected to be a byte string.
 
 =head2 from_hex_seed
 
-	sig: from_hex_seed($class, $seed)
+	$key_object = $class->from_hex_seed($seed)
 
-Same as from_seed, but $seed is treated as hex string.
+Same as C<from_seed>, but C<$seed> is treated as hex string.
 
 =head2 to_serialized
 
-	sig: to_serialized($self)
+	$serialized = $object->to_serialized()
 
 Returns the key serialized in format specified in BIP32 as byte string.
 
 =head2 to_serialized_base58
 
-	sig: to_serialized_base58($self)
+	$serialized_base58 = $object->to_serialized_base58()
 
-Behaves the same as to_serialized(), but performs Base58Check encoding on the resulting byte string.
+Behaves the same as C<to_serialized>, but performs Base58Check encoding on the resulting byte string.
 
 =head2 from_serialized
 
-	sig: from_serialized($class, $serialized, $network = undef)
+	$key_object = $class->from_serialized($serialized, $network = undef)
 
-Tries to unserialize byte string $serialized with format specified in BIP32.
+Tries to unserialize byte string C<$serialized> with format specified in BIP32.
 
-Dies on errors. If multiple networks match serialized data specify $network manually (id of the network) to avoid exception.
+Dies on errors. If multiple networks match serialized data specify C<$network> manually (id of the network) to avoid exception.
 
 =head2 from_serialized_base58
 
-	sig: from_serialized_base58($class, $base58, $network = undef)
+	$key_object = $class->from_serialized_base58($base58, $network = undef)
 
-Same as from_serialized, but performs Base58Check decoding on $base58 argument.
+Same as C<from_serialized>, but performs Base58Check decoding on C<$base58> argument.
 
 =head2 set_network
 
-	sig: set_network($self, $val)
+	$key_object = $object->set_network($val)
 
-Change key's network state to $val. It can be either network name present in Bitcoin::Crypto::Network package or an instance of this class.
+Change key's network state to C<$val>. It can be either network name present in L<Bitcoin::Crypto::Network> package or an instance of this class.
 
 Returns current key instance.
 
 =head2 get_public_key
 
-	sig: get_public_key($self)
+	$public_key_object = $object->get_public_key()
 
 Returns instance of L<Bitcoin::Crypto::Key::ExtPublic> generated from the private key.
 
 =head2 get_basic_key
 
-	sig: get_basic_key($self)
+	$basic_key_object = $object->get_basic_key()
 
 Returns the key in basic format: L<Bitcoin::Crypto::Key::Private>
 
 =head2 derive_key
 
-	sig: derive_key($self, $path)
+	$derived_key_object = $object->derive_key($path)
 
-Performs extended key derivation as specified in BIP32 on the current key with $path. Dies on error.
+Performs extended key derivation as specified in BIP32 on the current key with C<$path>. Dies on error.
 
 See BIP32 document for details on derivation paths and methods.
 
@@ -337,7 +334,7 @@ Returns a new extended key instance - result of a derivation.
 
 =head2 derive_key_bip44
 
-	sig: derive_key_bip44($self, %data)
+	$derived_key_object = $object->derive_key_bip44(%data)
 
 A helper that constructs a L<Bitcoin::Crypto::BIP44> path from C<%data> and calls L</derive_key> with it. Refer to L<Bitcoin::Crypto::BIP44/PROPERTIES> to see what you can include in C<%data>.
 
@@ -345,9 +342,9 @@ I<Note: coin_type parameter will be ignored, and the current network configurati
 
 =head2 get_fingerprint
 
-	sig: get_fingerprint($self, $len = 4)
+	$fingerprint = $object->get_fingerprint($len = 4)
 
-Returns a fingerprint of the extended key of $len length (byte string)
+Returns a fingerprint of the extended key of C<$len> length (byte string)
 
 =head1 EXCEPTIONS
 
