@@ -1,6 +1,6 @@
 package Bitcoin::Crypto::Key::Private;
 
-our $VERSION = "0.997";
+our $VERSION = "1.000";
 
 use v5.10;
 use warnings;
@@ -143,43 +143,43 @@ see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bit
 
 =head2 from_bytes
 
-	sig: from_bytes($class, $data)
+	$key_object = $class->from_bytes($data)
 
 Use this method to create a PrivateKey instance from a byte string.
-Data $data will be used as a private key entropy.
+Data C<$data> will be used as a private key entropy.
 
 Returns class instance.
 
 =head2 new
 
-	sig: new($class, $data)
+	$key_object = $class->new($data)
 
 This works exactly the same as from_bytes
 
 =head2 to_bytes
 
-	sig: to_bytes($self)
+	$bytestring = $object->to_bytes()
 
 Does the opposite of from_bytes on a target object
 
 =head2 from_hex
 
-	sig: from_hex($class, $hex)
+	$key_object = $class->from_hex($hex)
 
 Use this method to create a PrivateKey instance from a hexadecimal number.
-Number $hex will be used as a private key entropy.
+Number C<$hex> will be used as a private key entropy.
 
 Returns class instance.
 
 =head2 to_hex
 
-	sig: to_hex($self)
+	$hex_string = $object->to_hex()
 
 Does the opposite of from_hex on a target object
 
 =head2 from_wif
 
-	sig: from_wif($class, $str, $network = undef)
+	$key_object = $class->from_wif($str, $network = undef)
 
 Creates a new private key from Wallet Import Format string.
 
@@ -191,54 +191,66 @@ Returns class instance.
 
 =head2 to_wif
 
-	sig: to_wif($self)
+	$wif_string = $object->to_wif()
 
 Does the opposite of from_wif on a target object
 
 =head2 set_compressed
 
-	sig: set_compressed($self, $val)
+	$key_object = $object->set_compressed($val)
 
-Change key's compression state to $val (1/0). This will change the WIF generated by
+Change key's compression state to C<$val> (1/0). This will change the WIF generated by
 toWif() method and also enable creation of uncompressed public keys.
-If $val is omitted it is set to 1.
+If C<$val> is omitted it is set to 1.
 
 Returns current key instance.
 
 =head2 set_network
 
-	sig: set_network($self, $val)
+	$key_object = $object->set_network($val)
 
-Change key's network state to $val. It can be either network name present in Bitcoin::Crypto::Network package or an instance of this class.
+Change key's network state to C<$val>. It can be either network name present in Bitcoin::Crypto::Network package or an instance of this class.
 
 Returns current key instance.
 
 =head2 get_public_key
 
-	sig: get_public_key($self)
+	$public_key_object = $object->get_public_key()
 
 Returns instance of L<Bitcoin::Crypto::PublicKey> generated from the private key.
 
 =head2 sign_message
 
-	sig: sign_message($self, $message, $algo = "sha256")
+	$signature = $object->sign_message($message, $algo = "sha256")
 
-Signs a digest of $message (using $algo digest algorithm) with a private key.
+Signs a digest of C<$message> (using C<$algo> digest algorithm) with a private key.
 
-$algo must be available in L<Digest> package.
+C<$algo> must be available in L<Digest> package.
 
 Returns a byte string containing signature.
 
-Caution: libtomcrypt cryptographic package that is generating signatures does not currently offer a deterministic mechanism. For this reason the sign_message method will always complain with a warning until the RFC6797 procedure is implemented. Non-deterministic signatures can lead to leaking private keys if the random number generator's entropy is insufficient.
+Character encoding note: C<$message> should be encoded in the proper encoding before passing it to this method. Passing Unicode string will cause the function to fail. You can encode like this (for UTF-8):
+
+	use Encode qw(encode);
+	$message = encode('UTF-8', $message);
+
+Caution: libtomcrypt cryptographic package that is generating signatures does not currently offer a deterministic mechanism. For this reason the sign_message method will complain with a warning. You should install an optional L<Crypt::Perl> package, which supports deterministic signatures, which will disable the warning. Non-deterministic signatures can lead to leaking private keys if the random number generator's entropy is insufficient.
 
 =head2 verify_message
 
-	sig: verify_message($self, $message, $signature, $algo = "sha256")
+	$signature_valid = $object->verify_message($message, $signature, $algo = "sha256")
+
+Verifies C<$signature> against digest of C<$message> (with C<$algo> digest algorithm) using private key.
+
+C<$algo> must be available in Digest package.
 
-Verifies $signature against digest of $message (with $algo digest algorithm) using private key.
-$algo must be available in Digest package.
 Returns boolean.
 
+Character encoding note: C<$message> should be encoded in the proper encoding before passing it to this method. Passing Unicode string will cause the function to fail. You can encode like this (for UTF-8):
+
+	use Encode qw(encode);
+	$message = encode('UTF-8', $message);
+
 =head1 EXCEPTIONS
 
 This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters an error. It can produce the following error types from the L<Bitcoin::Crypto::Exception> namespace:
