@@ -1,6 +1,6 @@
 package Bitcoin::Crypto::Key::Public;
 
-our $VERSION = "0.997";
+our $VERSION = "1.000";
 
 use v5.10;
 use warnings;
@@ -100,80 +100,86 @@ You can use a public key to:
 
 =head2 from_bytes
 
-	sig: from_bytes($class, $data)
+	$key_object = $class->from_bytes($data)
 
 Use this method to create a PublicKey instance from a byte string.
-Data $data must represent a public key in ASN X9.62 format.
+Data C<$data> must represent a public key in ASN X9.62 format.
 
 Returns class instance.
 
 =head2 new
 
-	sig: new($class, $data)
+	$key_object = $class->new($data)
 
 This works exactly the same as from_bytes
 
 =head2 to_bytes
 
-	sig: to_bytes($self)
+	$bytestring = $object->to_bytes()
 
-Does the opposite of from_bytes on a target object
+Does the opposite of C<from_bytes> on a target object
 
 =head2 from_hex
 
-	sig: from_hex($class, $hex)
+	$key_object = $class->from_hex($hex)
 
-Use this method to create a public key instance from a hexadecimal number. Packs the number and runs it through from_bytes.
+Use this method to create a public key instance from a hexadecimal number. Packs the number and runs it through C<from_bytes>.
 
 Returns class instance.
 
 =head2 to_hex
 
-	sig: to_hex($self)
+	$hex_string = $object->to_hex()
 
 Does the opposite of from_hex on a target object
 
 =head2 set_compressed
 
-	sig: set_compressed($self, $val)
+	$key_object = $object->set_compressed($val)
 
-Change key's compression state to $val (1/0). This will change the address.
-If $val is omitted it is set to 1.
+Change key's compression state to C<$val> (C<1>/C<0>). This will change the address.
+If C<$val> is omitted it is set to C<1>.
 
 Returns current key instance.
 
 =head2 set_network
 
-	sig: set_network($self, $val)
+	$key_object = $object->set_network($val)
 
-Change key's network state to $val. It can be either network name present in Bitcoin::Crypto::Network package or an instance of this class.
+Change key's network state to C<$val>. It can be either network name present in L<Bitcoin::Crypto::Network> package or an instance of this class.
 
 Returns current key instance.
 
 =head2 verify_message
 
-	sig: verify_message($self, $message, $signature, $algo = "sha256")
+	$signature_valid = $object->verify_message($message, $signature, $algo = "sha256")
 
-Verifies $signature against digest of $message (with $algo digest algorithm) using public key.
-$algo must be available in Digest package.
+Verifies C<$signature> against digest of C<$message> (with C<$algo> digest algorithm) using public key.
+
+C<$algo> must be available in Digest package.
 
 Returns boolean.
 
+Character encoding note: C<$message> should be encoded in the proper encoding before passing it to this method. Passing Unicode string will cause the function to fail. You can encode like this (for UTF-8):
+
+	use Encode qw(encode);
+	$message = encode('UTF-8', $message);
+
 =head2 get_legacy_address
 
-	sig: get_legacy_address($self)
+	$address_string = $object->get_legacy_address()
 
 Returns string containing Base58Check encoded public key hash (p2pkh address)
 
 =head2 get_compat_address
 
-	sig: get_compat_address($self)
+	$address_string = $object->get_compat_address()
 
 Returns string containing Base58Check encoded script hash containing a witness program for compatibility purposes (p2sh(p2wpkh) address)
 
 =head2 get_segwit_address
 
-	sig: get_segwit_address($self)
+	$address_string = $object->get_segwit_address()
 
 Returns string containing Bech32 encoded witness program (p2wpkh address)
 
