@@ -1,12 +1,15 @@
 package Bitcoin::Crypto::Util;
 
-our $VERSION = "0.997";
+our $VERSION = "1.000";
 
 use v5.10;
 use warnings;
 use Exporter qw(import);
 use List::Util qw(first);
 use Crypt::PK::ECC;
+use Unicode::Normalize;
+use Crypt::KeyDerivation qw(pbkdf2);
+use Encode qw(encode);
 
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Base58 qw(decode_base58check);
@@ -14,6 +17,7 @@ use Bitcoin::Crypto::Base58 qw(decode_base58check);
 our @EXPORT_OK = qw(
 	validate_wif
 	get_key_type
+	mnemonic_to_seed
 	get_path_info
 );
 
@@ -52,6 +56,16 @@ sub get_key_type
 	return;
 }
 
+sub mnemonic_to_seed
+{
+	my ($mnemonic, $password) = @_;
+
+	$mnemonic = encode("UTF-8", NFKD($mnemonic));
+	$password = encode("UTF-8", NFKD("mnemonic" . ($password // "")));
+
+	return pbkdf2($mnemonic, $password, 2048, "SHA512", 64);
+}
+
 sub get_path_info
 {
 	my ($path) = @_;
@@ -97,26 +111,37 @@ These are basic utilities for working with bitcoin, used by other packages.
 
 =head2 validate_wif
 
-	my $bool = validate_wif($str);
+	$bool = validate_wif($str);
 
 Ensures Base58 encoded string looks like encoded private key in WIF format.
-Throws an exception if $str is not valid base58.
+Throws an exception if C<$str> is not valid base58.
 
 =head2 get_key_type
 
-	my $is_private = get_key_type($bytestr);
+	$is_private = get_key_type($bytestr);
 
-Checks if the $bytestr looks like a valid ASN X9.62 format (compressed / uncompressed / hybrid public key or private key entropy up to curve size bits).
+Checks if the C<$bytestr> looks like a valid ASN X9.62 format (compressed / uncompressed / hybrid public key or private key entropy up to curve size bits).
 Returns boolean which can be used to determine if the key is private.
-Returns undef if $bytestr does not look like a valid key entropy.
+Returns undef if C<$bytestr> does not look like a valid key entropy.
+
+=head2 mnemonic_to_seed
+
+	$seed = mnemonic_to_seed($mnemonic, $password);
+
+Transforms the given BIP39 C<$mnemonic> and C<$password> into a valid BIP32 C<$seed>, which can be fed into L<Bitcoin::Crypto::Key::ExtPrivate/from_seed>.
+
+C<$seed> is a 512 bit bytestring (64 characters). C<$mnemonic> should be a BIP39 mnemonic, but will not be checked against a dictionary.
+
+This function is only useful if you need a seed instead of mnemonic (for example, you use a wallet implementation which does not implement BIP39). If you only want to create a private key from mnemonic, you should consider using L<Bitcoin::Crypto::Key::ExtPrivate/from_mnemonic> instead.
+
+B<Important note about unicode:> this function only accepts UTF8-decoded strings (both C<$mnemonic> and C<$password>), but can't detect whether it got it or not. This will only become a problem if you use non-ascii mnemonic and/or password. If there's a possibility of non-ascii, always use utf8 and set binmodes to get decoded (wide) characters to avoid problems recovering your wallet.
 
 =head2 get_path_info
 
-	my $path = "m/1/3'";
-	my $path_data = get_path_info($path);
+	$path_data = get_path_info($path);
 
-Tries to get derivation path data from $path.
-Returns undef if $path is not a valid path.
+Tries to get derivation path data from C<$path>.
+Returns undef if C<$path> is not a valid path.
 Otherwise returns the structure:
 
 	{
@@ -127,6 +152,11 @@ Otherwise returns the structure:
 		],
 	}
 
+Example:
+
+	my $path = "m/1/3'";
+	my $path_data = get_path_info($path);
+
 =head1 SEE ALSO
 
 =over 2
